betty.project.extension.demo.project module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.project.extension.demo.project module

Provide the demonstration project.

async betty.project.extension.demo.project.create_project(app: App, project_directory_path: Path) → Project

  Create a new demonstration project.

async betty.project.extension.demo.project.load_ancestry(project: Project) → None

  Load the demo ancestry.

  This is internal. It MAY be used anywhere in Betty’s source code, but MUST NOT be used by third-party code.